@@ -163,26 +163,36 @@ sub _build_from {
     $h->{from} = $me->_build_table(($me->tables)[0]);
     for (my $i = 1; $i < $me->tables; $i++) {
         $h->{from} .= $h->{Join}[$i].$me->_build_table(($me->tables)[$i]);
-        if ($h->{JoinOn}[$i]) {
-            $h->{from} .= ' ON '.join(' AND ', $me->_build_where_chunk($h->{From_Bind}, 'OR', $h->{JoinOn}[$i]));
+        if ($h->{Join_On}[$i]) {
+            $h->{from} .= ' ON '.join(' AND ', $me->_build_where_chunk($h->{From_Bind}, 'OR', $h->{Join_On}[$i]));
         }
     }
     $h->{from};
 }
 
-sub _parse_col {
+sub _valid_col {
     my ($me, $col) = @_;
-    if (blessed $col and $col->isa('DBIx::DBO::Column')) {
-        for my $tbl ($me->tables) {
-            return $col if $col->[0] == $tbl;
-        }
-        # TODO: Flesh out this ouch a bit
-        ouch 'Invalid table';
+    for my $tbl ($me->tables) {
+        return $col if $col->[0] == $tbl;
+    }
+    ouch 'Invalid column, the column is from a table not included in this query';
+}
+
+sub _parse_col {
+    my ($me, $col, $_chk_aliases) = @_;
+    if (ref $col) {
+        return $me->_valid_col($col) if blessed $col and $col->isa('DBIx::DBO::Column');
+        ouch 'Invalid column: '.$col;
     }
-    ouch 'Invalid column: '.$col if ref $col;
     for my $tbl ($me->tables) {
         return $tbl->column($col) if exists $tbl->{Column_Idx}{$col};
     }
+    if ($_chk_aliases) {
+        for my $fld (@{$me->{build_data}{Showing}}) {
+            return \($me->_qi($col))
+                if !blessed $fld and exists $fld->[2]{AS} and $col eq $fld->[2]{AS};
+        }
+    }
     ouch 'No such column: '.$col;
 }
 
@@ -194,12 +204,12 @@ sub _build_col {
 sub _parse_val {
     my $me = shift;
     my $fld = shift;
-    my $check_fld = shift || '';
+    my %c = (Check => '', @_);
 
     my $func;
     my %opt;
     if (ref $fld eq 'SCALAR') {
-        ouch 'Invalid '.($check_fld eq 'Column' ? 'column' : 'field').' reference (scalar ref to undef)'
+        ouch 'Invalid '.($c{Check} eq 'Column' ? 'column' : 'field').' reference (scalar ref to undef)'
             unless defined $$fld;
         $func = $$fld;
         $fld = [];
@@ -213,10 +223,12 @@ sub _parse_val {
         $opt{COLLATE} = $fld->{COLLATE} if exists $fld->{COLLATE};
         if (exists $fld->{COL}) {
             ouch 'Invalid HASH containing both COL and VAL' if exists $fld->{VAL};
-            $fld = $me->_parse_col($fld->{COL});
+            $fld = $me->_parse_col($fld->{COL}, $c{Aliases});
         } else {
             $fld = exists $fld->{VAL} ? $fld->{VAL} : [];
         }
+    } elsif (blessed $fld and $fld->isa('DBIx::DBO::Column')) {
+        return [ $me->_valid_col($fld) ];
     }
     $fld = [$fld] unless ref $fld eq 'ARRAY';
 
@@ -225,8 +237,8 @@ sub _parse_val {
     if (defined $func) {
         my $need = $me->_substitute_placeholders($func);
         ouch "The number of params ($with) does not match the number of placeholders ($need)" if $need != $with;
-    } elsif ($with != 1 and $check_fld ne 'Auto') {
-        ouch 'Invalid '.($check_fld eq 'Column' ? 'column' : 'field')." reference (passed $with params instead of 1)";
+    } elsif ($with != 1 and $c{Check} ne 'Auto') {
+        ouch 'Invalid '.($c{Check} eq 'Column' ? 'column' : 'field')." reference (passed $with params instead of 1)";
     }
     return ($fld, $func, \%opt);
 }
@@ -269,6 +281,7 @@ sub _build_val {
     return $func.$extra;
 }
 
+# Construct the WHERE clause
 sub _build_where {
     my $me = shift;
     my $h = shift;
@@ -280,6 +293,7 @@ sub _build_where {
     $h->{where} = join ' AND ', @where;
 }
 
+# Construct the WHERE contents of one set of parentheses
 sub _build_where_chunk {
     my $me = shift;
     my ($bind, $ag, $whs) = @_;
@@ -320,11 +334,13 @@ sub _op_ag {
     return 'AND' if $_[0] eq '!=' or $_[0] eq 'IS NOT' or $_[0] eq '<>' or $_[0] eq 'NOT IN' or $_[0] eq 'NOT BETWEEN';
 }
 
+# Construct one WHERE expression
 sub _build_where_piece {
     my ($me, $bind, $op, $fld, $fld_func, $fld_opt, $val, $val_func, $val_opt) = @_;
     $me->_build_val($bind, $fld, $fld_func, $fld_opt)." $op ".$me->_build_val($bind, $val, $val_func, $val_opt);
 }
 
+# Construct one WHERE expression (simple)
 sub _build_quick_where {
     ouch 'Wrong number of arguments' if @_ & 1;
     my ($me, $bind) = splice @_, 0, 2;
